'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

const index = require('./index-c9014d38.js');
const analytic_constants = require('./analytic.constants-12a9229f.js');
const util_service = require('./util.service-0939076e.js');
const subscription_service_factory = require('./subscription.service.factory-21094270.js');
const axios_factory = require('./axios.factory-cf2c39e0.js');
const security_service_factory = require('./security.service.factory-a880f593.js');
const recommendation_service_factory = require('./recommendation.service.factory-ceaf4685.js');
const componentFactory = require('./componentFactory-568aa630.js');

const allAppsComponentCss = ".btn-all-apps{background-color:#0a4fb4}.btn-all-apps:hover{background-color:#007dff}.tile{margin:0;transition:background-color .2s}.tile>div:first-child{align-items:center;-moz-column-gap:8px;column-gap:8px;font-weight:500;margin-bottom:8px;opacity:.8}.tile div>svg{opacity:.5}.tile img.logo{margin-bottom:12px;width:250px}.tile p{font-size:1rem;margin-bottom:1rem;text-overflow:ellipsis}.tile button{align-items:center;-moz-column-gap:4px;column-gap:4px;display:flex;font-weight:600}.modal-content>div>.text-white{font-size:1rem}.recommended-apps-title{color:#10398d;font-family:Barlow Condensed,sans-serif;font-size:20px;font-weight:500;line-height:24px}.stack-blue-text{color:#48749b;line-height:20px}.paragraph{height:150px}.blue-button{background-color:#0072eb;color:#fff}.details-btn{color:#fff;font-family:Barlow,sans-serif;font-size:16px;font-weight:600;line-height:19px;transition:width 2s ease-in-out}img.logo{height:75px;width:250px}@-webkit-keyframes fadeIn{0%{opacity:0}to{opacity:1}}@keyframes fadeIn{0%{opacity:0}to{opacity:1}}.subscription-category-title{color:#020202;font-family:Barlow Condensed,sans-serif;font-size:14px;font-weight:500;letter-spacing:0;line-height:17px;opacity:1;text-align:left;text-transform:uppercase}@-webkit-keyframes fadeOut{0%{opacity:1}to{opacity:0}}@keyframes fadeOut{0%{opacity:1}to{opacity:0}}@-webkit-keyframes close-animation{0%{transform:rotate(0deg)}to{transform:rotate(-1turn)}}@keyframes close-animation{0%{transform:rotate(0deg)}to{transform:rotate(-1turn)}}@-webkit-keyframes open-animation{0%{transform:rotate(0deg)}to{transform:rotate(1turn)}}@keyframes open-animation{0%{transform:rotate(0deg)}to{transform:rotate(1turn)}}";

const maxTextLength = 270;
const txtLearnMore = 'Learn More';
const txtContinue = 'Continue';
const subscriptionService = subscription_service_factory.SubscriptionServiceFactory.GetInstance();
const AllAppsComponent = class {
  constructor(hostRef) {
    index.registerInstance(this, hostRef);
    this.buttonText = {};
  }
  async loadData() {
    analytic_constants.state.subscriptions = [];
    subscriptionService.enumerateSubscriptions().then(x => {
      analytic_constants.state.subscriptions = [...x];
      analytic_constants.state.subscriptions.forEach(x => {
        this.buttonText[x.subscriptionId] = txtLearnMore;
      });
    });
    analytic_constants.state.scopedCorrelationId = axios_factory.AnalyticsServiceFactory.Singleton.createCorrleationId();
    axios_factory.AnalyticsServiceFactory.Singleton.notifyThrottle({
      category: analytic_constants.ClickStreamCategory.AllAppsDialog,
      capturedMetrics: {
        action: analytic_constants.ClickStreamAction.Opened,
        correlationId: analytic_constants.state.scopedCorrelationId,
        sourceSubscriptionTitle: analytic_constants.state.currentSubscription.title,
        timeClicked: new Date(),
      },
    });
  }
  injectCarousel(model) {
    const element = this.el.getElementsByClassName('subscription-carousel-ph')[0];
    const htmlElement = document.createElement('subscription-carousel');
    analytic_constants.state.selectedSubscription = model;
    element.appendChild(htmlElement);
    htmlElement.presentAppDetailsModal(model);
    axios_factory.AnalyticsServiceFactory.Singleton.notifyThrottle({
      category: analytic_constants.ClickStreamCategory.AllAppsDialogViewDetails,
      capturedMetrics: {
        action: analytic_constants.ClickStreamAction.Clicked,
        correlationId: analytic_constants.state.scopedCorrelationId,
        sourceSubscriptionId: analytic_constants.state.selectedSubscription.subscriptionId,
        sourceSubscriptionTitle: analytic_constants.state.selectedSubscription.title,
        timeClicked: new Date(),
      },
    });
  }
  truncateDescription(description, length) {
    if (description && description.length > length) {
      return `${description.substring(0, length)}...`;
    }
    return description;
  }
  trackClose() {
    axios_factory.AnalyticsServiceFactory.Singleton.notifyThrottle({
      category: analytic_constants.ClickStreamCategory.AllAppsDialog,
      capturedMetrics: {
        action: analytic_constants.ClickStreamAction.Closed,
        correlationId: analytic_constants.state.scopedCorrelationId,
        timeClicked: new Date(),
      },
    });
  }
  beginButtonTransition(id, text) {
    this.buttonText[id] = text;
    this.buttonText = Object.assign({}, this.buttonText);
  }
  getText(id) {
    if (!id) {
      return txtLearnMore;
    }
    return this.buttonText[id];
  }
  render() {
    return (index.h(index.Host, null, index.h("marketplace-modal", { id: "all-apps-modal", width: "900px", onDialogClosed: _ => this.trackClose(), onDialogOpening: _ => this.loadData(), ref: el => (this.dialog = el) }, index.h("ul", { slot: "activator", class: "flex flex-row rounded cursor-pointer  btn-all-apps", id: "all-apps" }, index.h("li", { class: "cursor-pointer" }, index.h("div", { class: " flex  font-semibold text-14 flex text-white  p-2 rounded whitespace-nowrap cursor:pointer" }, index.h("span", { class: "font-bold text-xs" }, "All Apps")))), index.h("div", { slot: "content" }, index.h("div", { class: "py-2 ml-2 mr-2 recommended-apps-title" }, "Recommended Apps"), index.h("div", { class: "md:grid md:grid-cols-3 md:grid-rows-3 md:grid-flow-row md:gap-1 overflow-y-auto" }, analytic_constants.state.subscriptions.map(util_service.UtilService.mapSubscription).map(mapped => {
      var _a, _b, _c, _d;
      return (index.h("div", { class: "tile rounded-lg px-2  cursor-pointer mb-6", onClick: _ => this.injectCarousel(mapped.subscription) }, index.h("div", { class: "focus:outline-none  flex relative " }, index.h("span", { class: " subscription-category-title whitespace-nowrap", title: util_service.UtilService.getCategory((_a = mapped === null || mapped === void 0 ? void 0 : mapped.subscription) === null || _a === void 0 ? void 0 : _a.metadata, 100) }, util_service.UtilService.getCategory((_b = mapped === null || mapped === void 0 ? void 0 : mapped.subscription) === null || _b === void 0 ? void 0 : _b.metadata, 100))), index.h("div", null, index.h("img", { src: util_service.UtilService.getLogoDark(mapped === null || mapped === void 0 ? void 0 : mapped.subscription.metadata, index.getAssetPath), class: "logo" })), index.h("div", { class: "paragraph overflow-hidden" }, index.h("span", { class: "stack-blue-text  text-xs font-medium text-left" }, this.truncateDescription((_c = mapped === null || mapped === void 0 ? void 0 : mapped.subscription) === null || _c === void 0 ? void 0 : _c.description, maxTextLength))), index.h("div", { class: "my-1" }, index.h("button", { class: "details-btn focus:outline-none   mt-2 pl-5 pr-5 pt-2 pb-2 blue-button rounded-md", onMouseEnter: () => { var _a; return this.beginButtonTransition((_a = mapped === null || mapped === void 0 ? void 0 : mapped.subscription) === null || _a === void 0 ? void 0 : _a.subscriptionId, txtContinue); }, onMouseLeave: () => { var _a; return this.beginButtonTransition((_a = mapped === null || mapped === void 0 ? void 0 : mapped.subscription) === null || _a === void 0 ? void 0 : _a.subscriptionId, txtLearnMore); } }, index.h("span", { class: "text-left" }, " ", this.getText((_d = mapped === null || mapped === void 0 ? void 0 : mapped.subscription) === null || _d === void 0 ? void 0 : _d.subscriptionId))))));
    })), index.h("div", { class: "subscription-carousel-ph" })))));
  }
  get el() { return index.getElement(this); }
};
AllAppsComponent.style = allAppsComponentCss;

const marketConnectComponentCss = ".modal{transition:opacity .25s ease}.btn-marketplace-connect{background-color:#0a4fb4;transition:background-color .15s}.btn-marketplace-connect:hover{background-color:#007dff}@-webkit-keyframes fadeIn{0%{opacity:0}to{opacity:1}}@keyframes fadeIn{0%{opacity:0}to{opacity:1}}@-webkit-keyframes fadeOut{0%{opacity:1}to{opacity:0}}@keyframes fadeOut{0%{opacity:1}to{opacity:0}}@-webkit-keyframes close-animation{0%{transform:rotate(0deg)}to{transform:rotate(-1turn)}}@keyframes close-animation{0%{transform:rotate(0deg)}to{transform:rotate(-1turn)}}@-webkit-keyframes open-animation{0%{transform:rotate(0deg)}to{transform:rotate(1turn)}}@keyframes open-animation{0%{transform:rotate(0deg)}to{transform:rotate(1turn)}}";

const MarketConnectComponent = class {
  constructor(hostRef) {
    index.registerInstance(this, hostRef);
    this.buttonClicked = index.createEvent(this, "buttonClicked", 7);
  }
  toggleToolbar() {
    var _a, _b;
    const p = this.el.querySelector('.plus');
    const m = this.el.querySelector('.minus');
    (_a = p === null || p === void 0 ? void 0 : p.classList) === null || _a === void 0 ? void 0 : _a.toggle('hidden');
    (_b = m === null || m === void 0 ? void 0 : m.classList) === null || _b === void 0 ? void 0 : _b.toggle('hidden');
    analytic_constants.state.toolbarState = analytic_constants.state.toolbarState === 'open' ? 'closed' : 'open';
    this.buttonClickedHandler(analytic_constants.state.toolbarState);
  }
  buttonClickedHandler(state) {
    this.buttonClicked.emit(state);
  }
  componentWillLoad() {
    analytic_constants.state.toolbarState = 'closed';
  }
  render() {
    return (index.h("div", { onClick: _ => this.toggleToolbar(), class: "flex items-center btn-marketplace-connect relative cursor-pointer text-14 font-semibold  text-white   py-1 px-3 whitespace-nowrap" }, index.h("div", { class: "flex items-center" }, index.h("svg", { xmlns: "http://www.w3.org/2000/svg", class: "h-4 w-4 state-button state-icon plus", fill: "none", viewBox: "0 0 24 24", stroke: "currentColor" }, index.h("path", { "stroke-linecap": "round", "stroke-linejoin": "round", "stroke-width": "2", d: "M12 4v16m8-8H4" })), index.h("svg", { xmlns: "http://www.w3.org/2000/svg", class: "h-4 w-4 state-button  state-icon hidden minus", fill: "none", viewBox: "0 0 24 24", stroke: "currentColor" }, index.h("path", { "stroke-linecap": "round", "stroke-linejoin": "round", "stroke-width": "2", d: "M6 18L18 6M6 6l12 12" })), index.h("span", { class: "hidden ml-1  lg:block" }, "Marketplace Connect"))));
  }
  get el() { return index.getElement(this); }
};
MarketConnectComponent.style = marketConnectComponentCss;

const myAppsComponentCss = ".my-apps{background-color:#0d194f}.my-apps:hover{background-color:#007dff}.stack-blue-800{background-color:#0d194f}.subscription-item:hover{background-color:#e5f1ff}";

const security = security_service_factory.SecurityServiceFactory.GetInstance();
const MyApps = class {
  constructor(hostRef) {
    index.registerInstance(this, hostRef);
    this.visible = false;
    this.popoverActive = false;
  }
  setSubscriptionId(id) {
    security.proxySsoRequest(analytic_constants.state.currentSubscriptionId, id);
  }
  render() {
    return [
      index.h("div", { class: "cursor-pointer" }, index.h("ul", { class: "flex flex-row  rounded text-14 flex text-white my-apps " }, index.h("li", { class: "cursor-pointer" }, index.h("div", { class: " flex font-semibold  p-2 mr- rounded whitespace-nowrap cursor:pointer", onClick: _ => { var _a; return (_a = this === null || this === void 0 ? void 0 : this.popover) === null || _a === void 0 ? void 0 : _a.show(); } }, index.h("span", { class: "ml-1 font-bold text-xs mr-2" }, "My Apps"), index.h("svg", { xmlns: "http://www.w3.org/2000/svg", class: "h-4 w-4 ", fill: "none", viewBox: "0 0 20 20", stroke: "currentColor" }, index.h("path", { "stroke-linecap": "round", "stroke-linejoin": "round", "stroke-width": "2", d: "M19 9l-7 7-7-7" }))), index.h("my-apps-popover", { ref: el => (this.popover = el) })))),
    ];
  }
  get el() { return index.getElement(this); }
};
MyApps.style = myAppsComponentCss;

const recommendedAppsComponentCss = ".modal{transition:opacity .25s ease}.recommendation-btn{transition:background-color .15s}.recommendation-btn:hover{background-color:#0a4fb4;color:#fff}.recommendation-btn span:hover{color:#fff}.recommendations-list{overflow-x:auto}.stack-font-color{color:#a0cdfe}";

const service = recommendation_service_factory.RecommendationServiceFactory.GetInstance();
const RecommendApps = class {
  constructor(hostRef) {
    index.registerInstance(this, hostRef);
  }
  async presentAppDetailsModal(app) {
    analytic_constants.state.selectedSubscription = app;
    analytic_constants.state.currentIcon = util_service.UtilService.getSvgIcon(analytic_constants.state.selectedSubscription);
    this.dialogComponent.openDialog();
  }
  async dismissAppDetailsPopover() {
    // dismiss the closest modal and optionally pass back data
    this.el.closest('ion-modal').dismiss({
      dismissed: true,
    });
  }
  componentWillLoad() {
    if (!analytic_constants.state.recommendations || analytic_constants.state.recommendations.length <= 0) {
      service.getRecommendations(analytic_constants.state.identityId).then(x => {
        analytic_constants.state.recommendations = [...x];
      });
    }
  }
  setSlide() {
    var _a;
    (_a = this.carousel) === null || _a === void 0 ? void 0 : _a.reset();
    analytic_constants.state.scopedCorrelationId = axios_factory.AnalyticsServiceFactory.Singleton.createCorrleationId();
    axios_factory.AnalyticsServiceFactory.Singleton.notifyThrottle({
      category: analytic_constants.ClickStreamCategory.RecommendationDetailsDialog,
      capturedMetrics: {
        action: analytic_constants.ClickStreamAction.Opened,
        correlationId: analytic_constants.state.scopedCorrelationId,
        sourceSubscriptionId: analytic_constants.state.currentSubscriptionId,
        sourceSubscriptionTitle: analytic_constants.state.currentSubscription.title,
        timeClicked: new Date(),
      },
    });
  }
  handleBack() {
    this.carousel.goBack();
    this.pauseVideo();
  }
  pauseVideo() {
    const video = this.carousel.shadowRoot.querySelector('.marketing-video');
    if (video) {
      video.pause();
    }
    axios_factory.AnalyticsServiceFactory.Singleton.notifyThrottle({
      category: analytic_constants.ClickStreamCategory.RecommendationDetailsDialog,
      capturedMetrics: {
        action: analytic_constants.ClickStreamAction.Closed,
        correlationId: analytic_constants.state.scopedCorrelationId,
        sourceSubscriptionId: analytic_constants.state.currentSubscriptionId,
        sourceSubscriptionTitle: analytic_constants.state.currentSubscription.title,
        timeClicked: new Date(),
      },
    });
    analytic_constants.state.scopedCorrelationId = undefined;
  }
  async presentPopup(e, app) {
    e.preventDefault();
    e.stopPropagation();
    analytic_constants.state.selectedSubscription = app;
    const popoverElement = await componentFactory.ComponenetFactory.injectComponenet(e.target.querySelector('#recommendation-popover-ph'), _ => {
      const element = document.createElement('recommendation-popover');
      element.classList.remove('hidden');
      return element;
    });
    this.recommendationpopover = popoverElement;
    this.recommendationpopover.classList.add('popover-active');
    util_service.UtilService.animateOnShow(this.recommendationpopover).then(_ => this.recommendationpopover.classList.add('popover-active'));
  }
  hidePopup(ev) {
    ev.preventDefault();
    ev.stopPropagation();
    let parent = ev.target.querySelector('#recommendation-popover-ph');
    if (!parent) {
      parent = ev.target;
    }
    componentFactory.ComponenetFactory.disposeComponenet(parent, this.recommendationpopover);
  }
  onSlideChange(e) {
    if (e && e.detail && e.detail.carouselItem) {
      const videos = e.detail.carouselItem.getElementsByTagName('video');
      if (videos.length > 0) {
        videos[0].pause();
      }
    }
  }
  render() {
    return [
      index.h("div", { class: "hidden lg:block" }, index.h("marketplace-modal", { id: "normal-recommendations-dialog", autoWireOpen: false, ref: el => (this.dialogComponent = el), onBackClicked: _ => this.handleBack(), onDialogOpening: _ => this.setSlide(), onDialogClosed: _ => this.pauseVideo(), width: "900px" }, index.h("div", { slot: "activator", class: "flex flex-row items-center recommendations-list  " }, index.h("label", { class: " text-14 p-2 stack-font-color whitespace-nowrap" }, "Recommended Apps:"), index.h("ul", { class: "flex flex-row", ref: el => (this.listComponent = el) }, analytic_constants.state.recommendations
        .map(x => util_service.UtilService.mapSubscription(x))
        .map(app => (index.h("li", { onClick: _ => this.presentAppDetailsModal(app.subscription), onMouseEnter: e => this.presentPopup(e, app.subscription), onMouseLeave: e => this.hidePopup(e), class: "relative cursor-pointer recommendation-btn rounded p-2 ml-2 mr-4 " }, index.h("div", { class: " flex stack-font-color font-semibold  text-14  whitespace-nowrap cursor:pointer" }, index.h("span", null, util_service.UtilService.getMetadataValue(app.subscription.metadata, 'category'))), index.h("div", { id: "recommendation-popover-ph" })))))), index.h("div", { slot: "content" }, index.h("marketing-carousel", { ref: el => (this.carousel = el), onSlideChanged: e => this.onSlideChange(e) })))),
    ];
  }
  get el() { return index.getElement(this); }
};
RecommendApps.style = recommendedAppsComponentCss;

exports.all_apps = AllAppsComponent;
exports.market_connect = MarketConnectComponent;
exports.my_apps = MyApps;
exports.recommended_apps = RecommendApps;
