import { Component, Host, h, Element, getAssetPath, State } from '@stencil/core';
import { SubscriptionServiceFactory, AnalyticsServiceFactory } from '../../factories';
import { UtilService } from '../../services';
import { ClickStreamCategory, ClickStreamAction } from '../../services';
import state from '../../store';
const maxTextLength = 270;
const txtLearnMore = 'Learn More';
const txtContinue = 'Continue';
const subscriptionService = SubscriptionServiceFactory.GetInstance();
export class AllAppsComponent {
  constructor() {
    this.buttonText = {};
  }
  async loadData() {
    state.subscriptions = [];
    subscriptionService.enumerateSubscriptions().then(x => {
      state.subscriptions = [...x];
      state.subscriptions.forEach(x => {
        this.buttonText[x.subscriptionId] = txtLearnMore;
      });
    });
    state.scopedCorrelationId = AnalyticsServiceFactory.Singleton.createCorrleationId();
    AnalyticsServiceFactory.Singleton.notifyThrottle({
      category: ClickStreamCategory.AllAppsDialog,
      capturedMetrics: {
        action: ClickStreamAction.Opened,
        correlationId: state.scopedCorrelationId,
        sourceSubscriptionTitle: state.currentSubscription.title,
        timeClicked: new Date(),
      },
    });
  }
  injectCarousel(model) {
    const element = this.el.getElementsByClassName('subscription-carousel-ph')[0];
    const htmlElement = document.createElement('subscription-carousel');
    state.selectedSubscription = model;
    element.appendChild(htmlElement);
    htmlElement.presentAppDetailsModal(model);
    AnalyticsServiceFactory.Singleton.notifyThrottle({
      category: ClickStreamCategory.AllAppsDialogViewDetails,
      capturedMetrics: {
        action: ClickStreamAction.Clicked,
        correlationId: state.scopedCorrelationId,
        sourceSubscriptionId: state.selectedSubscription.subscriptionId,
        sourceSubscriptionTitle: state.selectedSubscription.title,
        timeClicked: new Date(),
      },
    });
  }
  truncateDescription(description, length) {
    if (description && description.length > length) {
      return `${description.substring(0, length)}...`;
    }
    return description;
  }
  trackClose() {
    AnalyticsServiceFactory.Singleton.notifyThrottle({
      category: ClickStreamCategory.AllAppsDialog,
      capturedMetrics: {
        action: ClickStreamAction.Closed,
        correlationId: state.scopedCorrelationId,
        timeClicked: new Date(),
      },
    });
  }
  beginButtonTransition(id, text) {
    this.buttonText[id] = text;
    this.buttonText = Object.assign({}, this.buttonText);
  }
  getText(id) {
    if (!id) {
      return txtLearnMore;
    }
    return this.buttonText[id];
  }
  render() {
    return (h(Host, null,
      h("marketplace-modal", { id: "all-apps-modal", width: "900px", onDialogClosed: _ => this.trackClose(), onDialogOpening: _ => this.loadData(), ref: el => (this.dialog = el) },
        h("ul", { slot: "activator", class: "flex flex-row rounded cursor-pointer  btn-all-apps", id: "all-apps" },
          h("li", { class: "cursor-pointer" },
            h("div", { class: " flex  font-semibold text-14 flex text-white  p-2 rounded whitespace-nowrap cursor:pointer" },
              h("span", { class: "font-bold text-xs" }, "All Apps")))),
        h("div", { slot: "content" },
          h("div", { class: "py-2 ml-2 mr-2 recommended-apps-title" }, "Recommended Apps"),
          h("div", { class: "md:grid md:grid-cols-3 md:grid-rows-3 md:grid-flow-row md:gap-1 overflow-y-auto" }, state.subscriptions.map(UtilService.mapSubscription).map(mapped => {
            var _a, _b, _c, _d;
            return (h("div", { class: "tile rounded-lg px-2  cursor-pointer mb-6", onClick: _ => this.injectCarousel(mapped.subscription) },
              h("div", { class: "focus:outline-none  flex relative " },
                h("span", { class: " subscription-category-title whitespace-nowrap", title: UtilService.getCategory((_a = mapped === null || mapped === void 0 ? void 0 : mapped.subscription) === null || _a === void 0 ? void 0 : _a.metadata, 100) }, UtilService.getCategory((_b = mapped === null || mapped === void 0 ? void 0 : mapped.subscription) === null || _b === void 0 ? void 0 : _b.metadata, 100))),
              h("div", null,
                h("img", { src: UtilService.getLogoDark(mapped === null || mapped === void 0 ? void 0 : mapped.subscription.metadata, getAssetPath), class: "logo" })),
              h("div", { class: "paragraph overflow-hidden" },
                h("span", { class: "stack-blue-text  text-xs font-medium text-left" }, this.truncateDescription((_c = mapped === null || mapped === void 0 ? void 0 : mapped.subscription) === null || _c === void 0 ? void 0 : _c.description, maxTextLength))),
              h("div", { class: "my-1" },
                h("button", { class: "details-btn focus:outline-none   mt-2 pl-5 pr-5 pt-2 pb-2 blue-button rounded-md", onMouseEnter: () => { var _a; return this.beginButtonTransition((_a = mapped === null || mapped === void 0 ? void 0 : mapped.subscription) === null || _a === void 0 ? void 0 : _a.subscriptionId, txtContinue); }, onMouseLeave: () => { var _a; return this.beginButtonTransition((_a = mapped === null || mapped === void 0 ? void 0 : mapped.subscription) === null || _a === void 0 ? void 0 : _a.subscriptionId, txtLearnMore); } },
                  h("span", { class: "text-left" },
                    " ",
                    this.getText((_d = mapped === null || mapped === void 0 ? void 0 : mapped.subscription) === null || _d === void 0 ? void 0 : _d.subscriptionId))))));
          })),
          h("div", { class: "subscription-carousel-ph" })))));
  }
  static get is() { return "all-apps"; }
  static get originalStyleUrls() { return {
    "$": ["all-apps-component.css"]
  }; }
  static get styleUrls() { return {
    "$": ["all-apps-component.css"]
  }; }
  static get states() { return {
    "buttonText": {}
  }; }
  static get elementRef() { return "el"; }
}
