import { Component, h, getAssetPath, State, Element, Method, Event } from '@stencil/core';
import state from '../../store';
import { UtilService } from '../../services';
import { AnalyticsServiceFactory } from '../../factories';
import { MimeTypes } from '../../models';
import { ClickStreamCategory, ClickStreamAction } from '../../services';
const txtGoToWebsite = 'Go To Website';
const txtContinue = 'Continue';
export class MarketingCarousel {
  constructor() {
    this.buttonText = txtGoToWebsite;
  }
  currentSubscription() {
    return [state.selectedSubscription];
  }
  componentWillLoad() {
    state.carouselSlideIndex = 0;
    this.transitionToSlide();
  }
  isVideo(url, contentType) {
    return MimeTypes.isVideo(url) || MimeTypes.isVideoContentType(contentType);
  }
  isImage(url, contentType) {
    return MimeTypes.isImage(url) || MimeTypes.isImageContentType(contentType);
  }
  beginButtonTransition(text) {
    this.buttonText = text;
  }
  getSlideElements(index) {
    var _a, _b;
    const ciSelector = `#carousel-item-${index}`;
    const pBtnSelector = `.prev`;
    const nBtnSelector = `.next`;
    const carouselItemContainer = (_b = (_a = this.el) === null || _a === void 0 ? void 0 : _a.shadowRoot) === null || _b === void 0 ? void 0 : _b.querySelector(ciSelector);
    const carouselItem = carouselItemContainer === null || carouselItemContainer === void 0 ? void 0 : carouselItemContainer.querySelector('.carousel-item');
    const next = carouselItemContainer === null || carouselItemContainer === void 0 ? void 0 : carouselItemContainer.querySelector(nBtnSelector);
    const prev = carouselItemContainer === null || carouselItemContainer === void 0 ? void 0 : carouselItemContainer.querySelector(pBtnSelector);
    return {
      carouselItemContainer,
      carouselItem,
      next,
      prev,
    };
  }
  showSlide() {
    var _a, _b, _c, _d, _e, _f, _g, _h;
    const elements = this.getSlideElements(state.carouselSlideIndex);
    (_b = (_a = elements.carouselItem) === null || _a === void 0 ? void 0 : _a.classList) === null || _b === void 0 ? void 0 : _b.add('carousel-item-active');
    (_d = (_c = elements.carouselItem) === null || _c === void 0 ? void 0 : _c.classList) === null || _d === void 0 ? void 0 : _d.remove('opacity-0');
    (_f = (_e = elements.next) === null || _e === void 0 ? void 0 : _e.classList) === null || _f === void 0 ? void 0 : _f.remove('opacity-0');
    (_h = (_g = elements.prev) === null || _g === void 0 ? void 0 : _g.classList) === null || _h === void 0 ? void 0 : _h.remove('opacity-0');
  }
  hideSlide(index) {
    var _a, _b, _c, _d, _e, _f, _g, _h;
    const elements = this.getSlideElements(index);
    (_b = (_a = elements.carouselItem) === null || _a === void 0 ? void 0 : _a.classList) === null || _b === void 0 ? void 0 : _b.remove('carousel-item-active');
    (_d = (_c = elements.carouselItem) === null || _c === void 0 ? void 0 : _c.classList) === null || _d === void 0 ? void 0 : _d.add('opacity-0');
    (_f = (_e = elements.next) === null || _e === void 0 ? void 0 : _e.classList) === null || _f === void 0 ? void 0 : _f.add('opacity-0');
    (_h = (_g = elements.prev) === null || _g === void 0 ? void 0 : _g.classList) === null || _h === void 0 ? void 0 : _h.add('opacity-0');
  }
  async transitionToSlide(from = 0) {
    this.showSlide();
    if (from >= 0) {
      this.onSlideChanged(this.getSlideElements(from));
      this.hideSlide(from);
      this.trackSlideChangeEvent();
    }
  }
  async reset() {
    this.transitionToSlide(-1);
    state.btnClicked = false;
  }
  async goBack() {
    state.btnClicked = false;
  }
  onSlideChanged(payload) {
    this.slideChanged.emit(payload);
  }
  next() {
    const currentIndex = state.carouselSlideIndex;
    let newIndex = ++state.carouselSlideIndex;
    if (newIndex >= state.selectedSubscription.marketing.length) {
      state.carouselSlideIndex = 0;
    }
    else {
      state.carouselSlideIndex = newIndex;
    }
    this.transitionToSlide(currentIndex);
  }
  prev() {
    const currentIndex = state.carouselSlideIndex;
    let newIndex = --state.carouselSlideIndex;
    if (newIndex < 0) {
      state.carouselSlideIndex = state.selectedSubscription.marketing.length - 1;
    }
    else {
      state.carouselSlideIndex = newIndex;
    }
    this.transitionToSlide(currentIndex);
  }
  contactSales() {
    state.btnClicked = true;
    state.backVisible = true;
  }
  trackButtonClick() {
    AnalyticsServiceFactory.Singleton.notifyThrottle({
      category: ClickStreamCategory.MarketingCarouselWebsiteButtonClicked,
      capturedMetrics: {
        action: ClickStreamAction.Clicked,
        correlationId: state.scopedCorrelationId,
        sourceSubscriptionId: state.selectedSubscription.subscriptionId,
        sourceSubscriptionTitle: state.selectedSubscription.title,
        timeClicked: new Date(),
      },
    });
    window.open(state.selectedSubscription.websiteUrl, '_blank');
  }
  trackSlideChangeEvent() {
    const data = state.selectedSubscription.marketing[state.carouselSlideIndex];
    if (!data) {
      return;
    }
    AnalyticsServiceFactory.Singleton.notifyThrottle({
      category: ClickStreamCategory.MarketingCarouselSlideChanged,
      capturedMetrics: {
        action: ClickStreamAction.SlideChanged,
        correlationId: state.scopedCorrelationId,
        sourceSubscriptionId: state.selectedSubscription.subscriptionId,
        sourceSubscriptionTitle: data.title,
        timeClicked: new Date(),
      },
    });
  }
  render() {
    return [
      h("div", { class: "grid grid-cols-2 items-center ml-20 mr-20 text-white" },
        this.currentSubscription()
          .map(UtilService.mapSubscription)
          .map(mapped => {
          var _a;
          return (h("div", { class: "tile rounded-lg  " },
            h("div", { class: "py-2 focus:outline-none  flex relative   text-xs whitespace-nowrap" },
              h("span", { class: "px-1  subscription-category-title " }, UtilService.getCategory((_a = mapped === null || mapped === void 0 ? void 0 : mapped.subscription) === null || _a === void 0 ? void 0 : _a.metadata))),
            h("div", null,
              h("img", { src: UtilService.getLogoDark(mapped === null || mapped === void 0 ? void 0 : mapped.subscription.metadata, getAssetPath), class: "logo" }))));
        }),
        h("div", null,
          h("div", { class: "flex justify-end justify-items-end" },
            h("ul", { class: "flex flex-row rounded cursor-pointer ", id: "contact-sales" },
              h("li", { class: "cursor-pointer btn-contact mr-2" }))))),
      h("div", { class: "flex flex-1 mb-5" }),
      h("div", { class: state.btnClicked ? 'static' : 'hidden' }),
      h("div", { class: `${state.btnClicked ? 'hidden' : 'carousel relative'}` },
        h("div", { class: "carousel-inner relative overflow-hidden w-full" }, state.selectedSubscription.marketing
          .map((m, i) => {
          return {
            model: m,
            current: i,
            next: i + 1 > state.selectedSubscription.marketing.length ? 0 : i + 1,
            prev: i - 1 < 0 ? state.selectedSubscription.marketing.length - 1 : i - 1,
            prevClass: i - 1 <= 0 ? 'hidden' : 'block',
            nextClass: i + 1 >= state.selectedSubscription.marketing.length ? 'hidden' : 'block',
            controlClass: `control-${i}`,
          };
        })
          .map(s => (h("div", { id: `carousel-item-${s.current}` },
          h("input", { class: "carousel-open hidden", type: "radio", id: `carousel-${s.current}`, name: "carousel", "aria-hidden": "true", checked: true }),
          h("div", { class: "carousel-item absolute opacity-0", style: { height: '263px' } },
            h("div", { class: "block h-full w-full  " },
              h("div", { class: "ml-20 mr-20 text-white" }, this.isVideo(s.model.screenshotUrl, s.model.contentType) ? (h("video", { width: "700", controls: true, class: "marketing-video" },
                h("source", { src: s.model.screenshotUrl, type: "video/mp4" }))) : this.isImage(s.model.screenshotUrl, s.model.contentType) ? (h("img", { src: s.model.screenshotUrl, width: 700, class: "rounded" })) : (h("iframe", { "v-else": true, width: "700", height: "380", src: s.model.screenshotUrl, title: s.model.title, frameborder: "0", allow: "accelerometer; clipboard-write; encrypted-media; gyroscope; picture-in-picture", allowFullScreen: true }))))),
          h("label", { id: `prev-btn-${s.current}`, onClick: _ => this.prev(), htmlFor: `carousel-${s.prev}`, class: `prev opacity-0 w-10 h-10 ml-1 md:ml-10 absolute cursor-pointer  text-5xl font-bold icon-chevron rounded-full bg-white leading-tight text-center z-10 inset-y-0 left-0 my-auto` }, "\u2039"),
          h("label", { id: `next-btn-${s.current}`, onClick: _ => this.next(), htmlFor: `carousel-${s.next}`, class: `next  opacity-0  w-10 h-10 mr-1 md:mr-10 absolute cursor-pointer  text-5xl font-bold icon-chevron rounded-full bg-white leading-tight text-center z-10 inset-y-0 right-0 my-auto` }, "\u203A"))))),
        h("div", { class: "ml-20 mr-20 mt-5" },
          h("p", { class: "stack-blue-text text-left" }, state.selectedSubscription.description)),
        h("div", { class: "flex justify-end" },
          h("div", { class: "mt-5 ml-20 mr-20", onMouseEnter: _ => this.beginButtonTransition(txtContinue), onMouseLeave: _ => this.beginButtonTransition(txtGoToWebsite) },
            h("button", { class: "bg-blue-500  details-btn  mt-2 pl-5 pr-5 pt-2 pb-2 rounded text-right", onClick: _ => this.trackButtonClick() },
              h("span", { class: "white" }, this.buttonText))))),
    ];
  }
  static get is() { return "marketing-carousel"; }
  static get encapsulation() { return "shadow"; }
  static get originalStyleUrls() { return {
    "$": ["marketing-carousel.css"]
  }; }
  static get styleUrls() { return {
    "$": ["marketing-carousel.css"]
  }; }
  static get states() { return {
    "buttonText": {}
  }; }
  static get events() { return [{
      "method": "slideChanged",
      "name": "slideChanged",
      "bubbles": true,
      "cancelable": true,
      "composed": true,
      "docs": {
        "tags": [],
        "text": ""
      },
      "complexType": {
        "original": "any",
        "resolved": "any",
        "references": {}
      }
    }]; }
  static get methods() { return {
    "transitionToSlide": {
      "complexType": {
        "signature": "(from?: number) => Promise<void>",
        "parameters": [{
            "tags": [],
            "text": ""
          }],
        "references": {
          "Promise": {
            "location": "global"
          }
        },
        "return": "Promise<void>"
      },
      "docs": {
        "text": "",
        "tags": []
      }
    },
    "reset": {
      "complexType": {
        "signature": "() => Promise<void>",
        "parameters": [],
        "references": {
          "Promise": {
            "location": "global"
          }
        },
        "return": "Promise<void>"
      },
      "docs": {
        "text": "",
        "tags": []
      }
    },
    "goBack": {
      "complexType": {
        "signature": "() => Promise<void>",
        "parameters": [],
        "references": {
          "Promise": {
            "location": "global"
          }
        },
        "return": "Promise<void>"
      },
      "docs": {
        "text": "",
        "tags": []
      }
    }
  }; }
  static get elementRef() { return "el"; }
}
