import { Component, h, Event, Element, Method, Prop } from '@stencil/core';
import { UtilService } from '../../services';
import state from '../../store';
export class MarketplaceModalComponent {
  constructor() {
    this.autoWireOpen = true;
    this.showBack = true;
    this.width = 'auto';
  }
  onBackClicked(payload) {
    this.backClicked.emit(payload);
  }
  onDialogOpening(payload) {
    this.dialogOpening.emit(payload);
  }
  onDialogClosed(payload) {
    this.dialogClosed.emit(payload);
  }
  async openDialog() {
    const modal = this.el.querySelector('.modal');
    modal.classList.toggle('opacity-0');
    modal.classList.toggle('pointer-events-none');
    document.body.classList.toggle('modal-open');
    this.onDialogOpening('opening');
  }
  dismiss() {
    const modal = this.el.querySelector('.modal');
    modal.classList.toggle('opacity-0');
    modal.classList.toggle('pointer-events-none');
    this.onDialogClosed('closed');
    document.body.classList.toggle('modal-open');
  }
  async presentModal() {
    const modal = this.el.querySelector('.modal');
    modal.classList.toggle('opacity-0');
    modal.classList.toggle('pointer-events-none');
    document.body.classList.toggle('modal-open');
    this.onDialogOpening('opening');
    this.width = '1000px';
  }
  render() {
    return [
      h("div", { class: "modal-activator cursor-pointer", onClick: _ => (this.autoWireOpen ? this.presentModal() : undefined) },
        h("slot", { name: "activator" })),
      h("div", { class: "modal opacity-0 pointer-events-none fixed w-full h-full top-0 left-0 flex items-center justify-center z-50" },
        h("div", { class: "modal-overlay absolute w-full h-full bg-gray-500 opacity-50 z-50 ", onClick: _ => this.dismiss() }),
        h("div", { class: "modal-container rounded-lg stack-white w-3/5 drop-shadow-3xl  rounded  z-50 xs:h-screen ", style: { width: this.width } },
          h("div", { class: "w-full h-full" },
            h("div", { class: "flex flex-row justify-center justify-items-center items-center stack-blue-800 rounded-tl-lg rounded-tr-lg p-2" },
              h("div", { class: state.backVisible ? 'block' : 'hidden' },
                h("svg", { class: "fill-current text-white cursor-pointer", xmlns: "http://www.w3.org/2000/svg", width: "28", height: "28", viewBox: "0 0 18 18", fill: "white" },
                  h("path", { "fill-rule": "evenodd", d: "M7.707 14.707a1 1 0 01-1.414 0l-4-4a1 1 0 010-1.414l4-4a1 1 0 011.414 1.414L5.414 9H17a1 1 0 110 2H5.414l2.293 2.293a1 1 0 010 1.414z", "clip-rule": "evenodd" }))),
              h("div", { class: "flex-1" }),
              h("div", null,
                h("img", { src: UtilService.getFromCdn('/Marketplace/S_Stack-Marketplace-Reverse_uqXHgfKOy.svg'), width: 200 })),
              h("div", { class: "flex-1" }),
              h("div", { class: "modal-close cursor-pointer", onClick: _ => this.dismiss() },
                h("svg", { class: "fill-current text-white", xmlns: "http://www.w3.org/2000/svg", width: "28", height: "28", viewBox: "0 0 18 18" },
                  h("path", { d: "M14.53 4.53l-1.06-1.06L9 7.94 4.53 3.47 3.47 4.53 7.94 9l-4.47 4.47 1.06 1.06L9 10.06l4.47 4.47 1.06-1.06L10.06 9z" })))),
            h("div", { class: "w-full h-full" },
              h("div", { class: " m-4 overflow-y-auto modal-content" },
                h("slot", { name: "content" })))))),
    ];
  }
  static get is() { return "marketplace-modal"; }
  static get originalStyleUrls() { return {
    "$": ["marketplace-modal-component.css"]
  }; }
  static get styleUrls() { return {
    "$": ["marketplace-modal-component.css"]
  }; }
  static get properties() { return {
    "autoWireOpen": {
      "type": "boolean",
      "mutable": false,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": ""
      },
      "attribute": "auto-wire-open",
      "reflect": false,
      "defaultValue": "true"
    },
    "showBack": {
      "type": "boolean",
      "mutable": false,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": ""
      },
      "attribute": "show-back",
      "reflect": false,
      "defaultValue": "true"
    },
    "width": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": ""
      },
      "attribute": "width",
      "reflect": false,
      "defaultValue": "'auto'"
    }
  }; }
  static get events() { return [{
      "method": "dialogOpening",
      "name": "dialogOpening",
      "bubbles": true,
      "cancelable": true,
      "composed": true,
      "docs": {
        "tags": [],
        "text": ""
      },
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      }
    }, {
      "method": "backClicked",
      "name": "backClicked",
      "bubbles": true,
      "cancelable": true,
      "composed": true,
      "docs": {
        "tags": [],
        "text": ""
      },
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      }
    }, {
      "method": "dialogClosed",
      "name": "dialogClosed",
      "bubbles": true,
      "cancelable": true,
      "composed": true,
      "docs": {
        "tags": [],
        "text": ""
      },
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      }
    }]; }
  static get methods() { return {
    "openDialog": {
      "complexType": {
        "signature": "() => Promise<void>",
        "parameters": [],
        "references": {
          "Promise": {
            "location": "global"
          }
        },
        "return": "Promise<void>"
      },
      "docs": {
        "text": "",
        "tags": []
      }
    }
  }; }
  static get elementRef() { return "el"; }
}
