import { Component, Host, h, Element, State, Event, Method } from '@stencil/core';
import { ComponenetFactory } from '../../componentFactory';
export class MarketplacePopover {
  constructor() {
    this.popoverState = false;
  }
  onOpening() {
    this.opening.emit();
  }
  async show() {
    this.onOpening();
    this.popoverState = true;
    this.el.classList.remove('hidden');
    const animation = this.el.animate([
      // keyframes
      { opacity: 0 },
      { opacity: 1 },
    ], {
      // timing options
      easing: 'ease-in',
      duration: 100,
      iterations: 1,
    });
    return animation.finished.then(_ => {
      this.el.classList.remove('opacity-0');
      this.el.classList.add('opacity-100');
      this.el.classList.add('popover-active');
    });
  }
  async isVisible() {
    return this.popoverState;
  }
  componentWillLoad() {
    this.popoverState = false;
  }
  closePopoverdHandler(state) {
    this.popoverState = false;
    this.closePopover.emit(state);
    const animation = this.el.animate([
      // keyframes
      { opacity: 1 },
      { opacity: 0 },
    ], {
      // timing options
      easing: 'ease-out',
      duration: 250,
      iterations: 1,
    });
    animation.finished.then(_ => {
      this.el.classList.add('opactiy-0');
      this.el.classList.remove('opacity-100');
      this.el.classList.remove('popover-active');
      this.el.classList.toggle('hidden');
      this.el.parentElement.removeChild(this.el);
    });
  }
  render() {
    return (h(Host, { class: "popover opacity-0 ", onMouseLeave: _ => this.closePopoverdHandler('closed') },
      h("slot", { name: "content" })));
  }
  static deactive(source, cssSelector, popover) {
    ComponenetFactory.disposeComponenet(source.querySelector(cssSelector), popover);
  }
  static activate(source, cssSelector, bodyComponent) {
    return ComponenetFactory.injectComponenet(source.querySelector(cssSelector), _ => {
      const popover = document.createElement('marketplace-popover');
      popover.innerHTML = bodyComponent;
      return popover;
    });
  }
  static get is() { return "marketplace-popover"; }
  static get originalStyleUrls() { return {
    "$": ["marketplace-popover.css"]
  }; }
  static get styleUrls() { return {
    "$": ["marketplace-popover.css"]
  }; }
  static get states() { return {
    "popoverState": {}
  }; }
  static get events() { return [{
      "method": "closePopover",
      "name": "closePopover",
      "bubbles": true,
      "cancelable": true,
      "composed": true,
      "docs": {
        "tags": [],
        "text": ""
      },
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      }
    }, {
      "method": "opening",
      "name": "opening",
      "bubbles": true,
      "cancelable": true,
      "composed": true,
      "docs": {
        "tags": [],
        "text": ""
      },
      "complexType": {
        "original": "any",
        "resolved": "any",
        "references": {}
      }
    }]; }
  static get methods() { return {
    "show": {
      "complexType": {
        "signature": "() => Promise<any>",
        "parameters": [],
        "references": {
          "Promise": {
            "location": "global"
          },
          "Animation": {
            "location": "global"
          }
        },
        "return": "Promise<any>"
      },
      "docs": {
        "text": "",
        "tags": []
      }
    },
    "isVisible": {
      "complexType": {
        "signature": "() => Promise<boolean>",
        "parameters": [],
        "references": {
          "Promise": {
            "location": "global"
          }
        },
        "return": "Promise<boolean>"
      },
      "docs": {
        "text": "",
        "tags": []
      }
    }
  }; }
  static get elementRef() { return "el"; }
}
