import { Component, Prop, h, Element, Watch, Host, State } from '@stencil/core';
import state from '../../store';
import { ClickStreamCategory, ClickStreamAction } from '../../services';
import { RecommendationServiceFactory, SubscriptionServiceFactory, AnalyticsServiceFactory, AxiosFactory } from '../../factories';
const subscriptionService = SubscriptionServiceFactory.GetInstance();
const recommendationService = RecommendationServiceFactory.GetInstance();
AxiosFactory.Configure();
/**
 *
 *
 * @export
 * @class MarketplaceToolbar
 * @description An easily distributable WebComponent providing authenticated users the ability to switch between participating Stack applications (PA).  A current prototype repository exists to explore the feasibility of such a utility.
 */
export class MarketplaceToolbar {
  constructor() {
    this.myAppsVisible = false;
    /**
     *
     *
     * @type {boolean}
     * @memberof MarketplaceToolbar
     * @description An identifier describing the current user context.  This will be used in conjunction with the application id to retrieve recommendations.
     */
    this.initialState = 'closed';
  }
  applicationIdHandler(newValue, _) {
    state.applicationId = newValue;
    state.currentSubscriptionId = newValue;
  }
  defaultColorHandler(newValue, _) {
    state.defaultColor = newValue;
  }
  versionIdHandler(newValue, _) {
    state.versionId = newValue;
  }
  identityIdHandler(newValue, _) {
    state.identityId = newValue;
  }
  async componentWillLoad() {
    state.toolbarState = this.initialState;
    state.applicationId = this.appId;
    state.currentSubscriptionId = this.appId;
    state.identityId = this.appId;
    state.defaultColor = this.defaultColor;
    state.versionId = this.versionId;
    this.buttonToggleCorrelationId = AnalyticsServiceFactory.Singleton.createCorrleationId();
    console.group('marketplace-toolbar');
    console.log('toolbarState:', this.initialState);
    console.log('applicationId:', this.appId);
    console.log('identityId:', this.identityId);
    console.log('defaultColor:', this.defaultColor);
    console.log('version', this.versionId);
    console.groupEnd();
    state.turnstileIdToken = window.sessionStorage.getItem('marketplace');
    window.sessionStorage.removeItem('marketplace');
    const mySubscriptions = await subscriptionService.enumerateMySubscriptions();
    state.sessionId = AnalyticsServiceFactory.Singleton.createCorrleationId();
    if (!(mySubscriptions === null || mySubscriptions === void 0 ? void 0 : mySubscriptions.subscriptions)) {
      this.myAppsVisible = false;
    }
    else {
      this.myAppsVisible = true;
      const subscriptions = mySubscriptions.subscriptions;
      state.trackingKey = mySubscriptions.trackingKey;
      console.log('tracking key', state.trackingKey);
      console.log('subscriptions', subscriptions.length);
      state.mySubscriptions = [...subscriptions.filter(x => x.subscriptionId != state.currentSubscriptionId)];
      state.currentSubscription = subscriptions.find(x => x.subscriptionId === state.currentSubscriptionId);
      console.log('my subscriptions', state.mySubscriptions.length);
      const myRecommendations = await recommendationService.getRecommendations(state.identityId);
      state.subscriptions = [...myRecommendations];
    }
  }
  componentDidLoad() {
    this.toggleToolbarState(undefined);
  }
  toggleToolbarState(_) {
    const model = {
      container: this.el.shadowRoot.querySelector('#toolbar-container'),
    };
    this.nav.classList.toggle('static');
    const isExpanding = model.container.classList.contains('collapsed');
    if (isExpanding) {
      state.defaultColor = 'rgb(15, 57, 141)';
    }
    else {
      state.defaultColor = this.defaultColor;
    }
    model.container.classList.toggle('collapsed');
    model.container.classList.toggle('expanded');
    AnalyticsServiceFactory.Singleton.notifyThrottle({
      category: ClickStreamCategory.MarketplaceConnectButtonClicked,
      capturedMetrics: {
        action: isExpanding ? ClickStreamAction.Opened : ClickStreamAction.Closed,
        correlationId: this.buttonToggleCorrelationId,
        sourceSubscriptionTitle: state.currentSubscription.title,
        timeClicked: new Date(),
      },
    });
    if (!isExpanding) {
      this.buttonToggleCorrelationId = AnalyticsServiceFactory.Singleton.createCorrleationId();
    }
  }
  get tid() {
    return state.turnstileIdToken;
  }
  render() {
    return (h(Host, { style: { 'z-index': '99999' } },
      h("nav", { class: "marketplace-toolbar static", ref: nav => (this.nav = nav), style: { 'background-color': state.defaultColor } },
        h("div", { class: "grid grid-cols-12 " },
          h("div", { id: "toolbar-container", class: "collapsed col-span-11" },
            h("div", { class: "flex flex-1", id: "toolbar-wrapper" },
              h("my-apps", { class: " md:p-2 my-apps-poper", visible: this.myAppsVisible, id: "my-apps" }),
              h("all-apps", { id: "all-apps", class: " md:p-2" }),
              h("recommended-apps", { id: "recommended-apps", class: " md:p-2 recommendations-list" }))),
          h("div", { id: "connect-btn", class: "flex flex-1 justify-end shadow" },
            h("market-connect", { id: "market-connect", class: "flex-0 flex justify-self-end ", onButtonClicked: ev => this.toggleToolbarState(ev) }))))));
  }
  static get is() { return "marketplace-toolbar"; }
  static get encapsulation() { return "shadow"; }
  static get originalStyleUrls() { return {
    "$": ["marketplace-toolbar.css"]
  }; }
  static get styleUrls() { return {
    "$": ["marketplace-toolbar.css"]
  }; }
  static get assetsDirs() { return ["assets"]; }
  static get properties() { return {
    "activated": {
      "type": "boolean",
      "mutable": false,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": ""
      },
      "attribute": "activated",
      "reflect": false
    },
    "appId": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [{
            "text": "{string}",
            "name": "type"
          }, {
            "text": "MarketplaceToolbar",
            "name": "memberof"
          }, {
            "text": "The consuming application's unique identifier.  This will be assigned when applications are integrated with Marketplace.",
            "name": "description"
          }],
        "text": ""
      },
      "attribute": "application-id",
      "reflect": false
    },
    "defaultColor": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": ""
      },
      "attribute": "default-color",
      "reflect": false
    },
    "versionId": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": ""
      },
      "attribute": "version-id",
      "reflect": false
    },
    "identityId": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [{
            "text": "{string}",
            "name": "type"
          }, {
            "text": "MarketplaceToolbar",
            "name": "memberof"
          }, {
            "text": "An identifier describing the current user context.  This will be used in conjunction with the application id to retrieve recommendations.",
            "name": "description"
          }],
        "text": ""
      },
      "attribute": "identity-id",
      "reflect": false
    },
    "initialState": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [{
            "text": "{boolean}",
            "name": "type"
          }, {
            "text": "MarketplaceToolbar",
            "name": "memberof"
          }, {
            "text": "An identifier describing the current user context.  This will be used in conjunction with the application id to retrieve recommendations.",
            "name": "description"
          }],
        "text": ""
      },
      "attribute": "initial-state",
      "reflect": false,
      "defaultValue": "'closed'"
    }
  }; }
  static get states() { return {
    "buttonToggleCorrelationId": {},
    "myAppsVisible": {}
  }; }
  static get elementRef() { return "el"; }
  static get watchers() { return [{
      "propName": "appId",
      "methodName": "applicationIdHandler"
    }, {
      "propName": "defaultColor",
      "methodName": "defaultColorHandler"
    }, {
      "propName": "versionId",
      "methodName": "versionIdHandler"
    }, {
      "propName": "identityId",
      "methodName": "identityIdHandler"
    }]; }
}
