import { Component, h, Element } from '@stencil/core';
import state from '../../store';
import { ClickStreamAction, ClickStreamCategory, UtilService } from '../../services';
import { RecommendationServiceFactory } from '../../factories';
import { ComponenetFactory } from '../../componentFactory';
import { AnalyticsServiceFactory } from '../../factories';
const service = RecommendationServiceFactory.GetInstance();
export class RecommendApps {
  async presentAppDetailsModal(app) {
    state.selectedSubscription = app;
    state.currentIcon = UtilService.getSvgIcon(state.selectedSubscription);
    this.dialogComponent.openDialog();
  }
  async dismissAppDetailsPopover() {
    // dismiss the closest modal and optionally pass back data
    this.el.closest('ion-modal').dismiss({
      dismissed: true,
    });
  }
  componentWillLoad() {
    if (!state.recommendations || state.recommendations.length <= 0) {
      service.getRecommendations(state.identityId).then(x => {
        state.recommendations = [...x];
      });
    }
  }
  setSlide() {
    var _a;
    (_a = this.carousel) === null || _a === void 0 ? void 0 : _a.reset();
    state.scopedCorrelationId = AnalyticsServiceFactory.Singleton.createCorrleationId();
    AnalyticsServiceFactory.Singleton.notifyThrottle({
      category: ClickStreamCategory.RecommendationDetailsDialog,
      capturedMetrics: {
        action: ClickStreamAction.Opened,
        correlationId: state.scopedCorrelationId,
        sourceSubscriptionId: state.currentSubscriptionId,
        sourceSubscriptionTitle: state.currentSubscription.title,
        timeClicked: new Date(),
      },
    });
  }
  handleBack() {
    this.carousel.goBack();
    this.pauseVideo();
  }
  pauseVideo() {
    const video = this.carousel.shadowRoot.querySelector('.marketing-video');
    if (video) {
      video.pause();
    }
    AnalyticsServiceFactory.Singleton.notifyThrottle({
      category: ClickStreamCategory.RecommendationDetailsDialog,
      capturedMetrics: {
        action: ClickStreamAction.Closed,
        correlationId: state.scopedCorrelationId,
        sourceSubscriptionId: state.currentSubscriptionId,
        sourceSubscriptionTitle: state.currentSubscription.title,
        timeClicked: new Date(),
      },
    });
    state.scopedCorrelationId = undefined;
  }
  async presentPopup(e, app) {
    e.preventDefault();
    e.stopPropagation();
    state.selectedSubscription = app;
    const popoverElement = await ComponenetFactory.injectComponenet(e.target.querySelector('#recommendation-popover-ph'), _ => {
      const element = document.createElement('recommendation-popover');
      element.classList.remove('hidden');
      return element;
    });
    this.recommendationpopover = popoverElement;
    this.recommendationpopover.classList.add('popover-active');
    UtilService.animateOnShow(this.recommendationpopover).then(_ => this.recommendationpopover.classList.add('popover-active'));
  }
  hidePopup(ev) {
    ev.preventDefault();
    ev.stopPropagation();
    let parent = ev.target.querySelector('#recommendation-popover-ph');
    if (!parent) {
      parent = ev.target;
    }
    ComponenetFactory.disposeComponenet(parent, this.recommendationpopover);
  }
  onSlideChange(e) {
    if (e && e.detail && e.detail.carouselItem) {
      const videos = e.detail.carouselItem.getElementsByTagName('video');
      if (videos.length > 0) {
        videos[0].pause();
      }
    }
  }
  render() {
    return [
      h("div", { class: "hidden lg:block" },
        h("marketplace-modal", { id: "normal-recommendations-dialog", autoWireOpen: false, ref: el => (this.dialogComponent = el), onBackClicked: _ => this.handleBack(), onDialogOpening: _ => this.setSlide(), onDialogClosed: _ => this.pauseVideo(), width: "900px" },
          h("div", { slot: "activator", class: "flex flex-row items-center recommendations-list  " },
            h("label", { class: " text-14 p-2 stack-font-color whitespace-nowrap" }, "Recommended Apps:"),
            h("ul", { class: "flex flex-row", ref: el => (this.listComponent = el) }, state.recommendations
              .map(x => UtilService.mapSubscription(x))
              .map(app => (h("li", { onClick: _ => this.presentAppDetailsModal(app.subscription), onMouseEnter: e => this.presentPopup(e, app.subscription), onMouseLeave: e => this.hidePopup(e), class: "relative cursor-pointer recommendation-btn rounded p-2 ml-2 mr-4 " },
              h("div", { class: " flex stack-font-color font-semibold  text-14  whitespace-nowrap cursor:pointer" },
                h("span", null, UtilService.getMetadataValue(app.subscription.metadata, 'category'))),
              h("div", { id: "recommendation-popover-ph" })))))),
          h("div", { slot: "content" },
            h("marketing-carousel", { ref: el => (this.carousel = el), onSlideChanged: e => this.onSlideChange(e) })))),
    ];
  }
  static get is() { return "recommended-apps"; }
  static get originalStyleUrls() { return {
    "$": ["recommended-apps-component.css"]
  }; }
  static get styleUrls() { return {
    "$": ["recommended-apps-component.css"]
  }; }
  static get elementRef() { return "el"; }
}
