import { Component, h, Element, Method, Event } from '@stencil/core';
import state from '../../store';
import { UtilService } from '../../services';
import { RecommendationServiceFactory } from '../../factories';
import { ComponenetFactory } from '../../componentFactory';
const service = RecommendationServiceFactory.GetInstance();
export class SubscriptionCarousel {
  async presentAppDetailsModal(app) {
    state.selectedSubscription = app;
    state.currentIcon = UtilService.getSvgIcon(state.selectedSubscription);
    this.dialogComponent.openDialog();
  }
  onDialogClosed(payload) {
    this.dialogClosed.emit(payload);
  }
  async dismissAppDetailsPopover() {
    // dismiss the closest modal and optionally pass back data
    this.el.closest('ion-modal').dismiss({
      dismissed: true,
    });
  }
  componentWillLoad() {
    if (!state.recommendations || state.recommendations.length <= 0) {
      service.getRecommendations(state.identityId).then(x => {
        state.recommendations = [...x];
      });
    }
  }
  setSlide() {
    var _a;
    (_a = this.carousel) === null || _a === void 0 ? void 0 : _a.reset();
  }
  handleBack() {
    this.carousel.goBack();
  }
  async presentPopup(e, app) {
    e.preventDefault();
    e.stopPropagation();
    state.selectedSubscription = app;
    const popoverElement = await ComponenetFactory.injectComponenet(e.target.querySelector('#recommendation-popover-ph'), _ => {
      const element = document.createElement('recommendation-popover');
      element.classList.remove('hidden');
      return element;
    });
    this.recommendationpopover = popoverElement;
    this.recommendationpopover.classList.add('popover-active');
    UtilService.animateOnShow(this.recommendationpopover).then(_ => this.recommendationpopover.classList.add('popover-active'));
  }
  hidePopup(ev) {
    ev.preventDefault();
    ev.stopPropagation();
    let parent = ev.target.querySelector('#recommendation-popover-ph');
    if (!parent) {
      parent = ev.target;
    }
    ComponenetFactory.disposeComponenet(parent, this.recommendationpopover);
  }
  render() {
    return [
      h("div", { class: "hidden lg:block" },
        h("marketplace-modal", { id: "normal-recommendations-dialog", autoWireOpen: false, ref: el => (this.dialogComponent = el), onBackClicked: _ => this.handleBack(), onDialogOpening: _ => this.setSlide(), onDialogClosed: e => this.onDialogClosed(e.detail), width: "1000px" },
          h("div", { slot: "content" },
            h("marketing-carousel", { ref: el => (this.carousel = el) })))),
    ];
  }
  static get is() { return "subscription-carousel"; }
  static get originalStyleUrls() { return {
    "$": ["subscription-carousel.css"]
  }; }
  static get styleUrls() { return {
    "$": ["subscription-carousel.css"]
  }; }
  static get events() { return [{
      "method": "dialogClosed",
      "name": "dialogClosed",
      "bubbles": true,
      "cancelable": true,
      "composed": true,
      "docs": {
        "tags": [],
        "text": ""
      },
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      }
    }]; }
  static get methods() { return {
    "presentAppDetailsModal": {
      "complexType": {
        "signature": "(app: any) => Promise<void>",
        "parameters": [{
            "tags": [],
            "text": ""
          }],
        "references": {
          "Promise": {
            "location": "global"
          }
        },
        "return": "Promise<void>"
      },
      "docs": {
        "text": "",
        "tags": []
      }
    },
    "dismissAppDetailsPopover": {
      "complexType": {
        "signature": "() => Promise<void>",
        "parameters": [],
        "references": {
          "Promise": {
            "location": "global"
          }
        },
        "return": "Promise<void>"
      },
      "docs": {
        "text": "",
        "tags": []
      }
    }
  }; }
  static get elementRef() { return "el"; }
}
