import axios from 'axios';
import state from '../store';
import { AbstractService } from './abstract.service';
import { v4 as uuidv4 } from 'uuid';
export class AnalyticsService extends AbstractService {
  constructor(config, bus) {
    super(config);
    this.config = config;
    this.bus = bus;
    this.analysisRoute = '/marketplace/api/v1/analytic-stream';
    this.bus.getMessage().subscribe(messages => {
      if (messages && messages.length >= 1) {
        this.publish(messages, `${this.baseUrl}${this.analysisRoute}`);
      }
    });
  }
  /**
   * throttles messages and dispatches them as an array.
   * @param message
   */
  notifyThrottle(message) {
    message.trackingKey = state.trackingKey;
    message.sessionId = state.sessionId;
    message.requestingClientId = state.currentSubscriptionId;
    this.bus.sendMessage(message);
  }
  /**
   * immediately publishes a single event.
   * @param message
   */
  async notifySync(message) {
    message.trackingKey = state.trackingKey;
    message.sessionId = state.sessionId;
    message.requestingClientId = state.currentSubscriptionId;
    //wait for any existing buffered messages to be released.  this sucks I need a better way!
    await this.wait(1001);
    this.publish([message], `${this.baseUrl}${this.analysisRoute}`);
  }
  wait(milliseconds) {
    return new Promise(resolve => setTimeout(resolve, milliseconds));
  }
  createCorrleationId() {
    return uuidv4();
  }
  async publish(payload, route) {
    if (payload && payload.length >= 1) {
      await axios.post(route, payload, {
        headers: {
          'Content-Type': 'application/json',
        },
      });
    }
  }
}
