import { r as registerInstance, h, c as getAssetPath, H as Host, a as getElement, d as createEvent } from './index-3adfa07d.js';
import { s as state, C as ClickStreamCategory, a as ClickStreamAction } from './analytic.constants-c757efc5.js';
import { U as UtilService } from './util.service-1c858ccc.js';
import { S as SubscriptionServiceFactory } from './subscription.service.factory-89900689.js';
import { a as AnalyticsServiceFactory } from './axios.factory-c895f8a2.js';
import { S as SecurityServiceFactory } from './security.service.factory-15cdc642.js';
import { R as RecommendationServiceFactory } from './recommendation.service.factory-edff1502.js';
import { C as ComponenetFactory } from './componentFactory-97ee8c5b.js';

const allAppsComponentCss = ".btn-all-apps{background-color:#0a4fb4}.btn-all-apps:hover{background-color:#007dff}.tile{margin:0;transition:background-color .2s}.tile>div:first-child{align-items:center;-moz-column-gap:8px;column-gap:8px;font-weight:500;margin-bottom:8px;opacity:.8}.tile div>svg{opacity:.5}.tile img.logo{margin-bottom:12px;width:250px}.tile p{font-size:1rem;margin-bottom:1rem;text-overflow:ellipsis}.tile button{align-items:center;-moz-column-gap:4px;column-gap:4px;display:flex;font-weight:600}.modal-content>div>.text-white{font-size:1rem}.recommended-apps-title{color:#10398d;font-family:Barlow Condensed,sans-serif;font-size:20px;font-weight:500;line-height:24px}.stack-blue-text{color:#48749b;line-height:20px}.paragraph{height:150px}.blue-button{background-color:#0072eb;color:#fff}.details-btn{color:#fff;font-family:Barlow,sans-serif;font-size:16px;font-weight:600;line-height:19px;transition:width 2s ease-in-out}img.logo{height:75px;width:250px}@-webkit-keyframes fadeIn{0%{opacity:0}to{opacity:1}}@keyframes fadeIn{0%{opacity:0}to{opacity:1}}.subscription-category-title{color:#020202;font-family:Barlow Condensed,sans-serif;font-size:14px;font-weight:500;letter-spacing:0;line-height:17px;opacity:1;text-align:left;text-transform:uppercase}@-webkit-keyframes fadeOut{0%{opacity:1}to{opacity:0}}@keyframes fadeOut{0%{opacity:1}to{opacity:0}}@-webkit-keyframes close-animation{0%{transform:rotate(0deg)}to{transform:rotate(-1turn)}}@keyframes close-animation{0%{transform:rotate(0deg)}to{transform:rotate(-1turn)}}@-webkit-keyframes open-animation{0%{transform:rotate(0deg)}to{transform:rotate(1turn)}}@keyframes open-animation{0%{transform:rotate(0deg)}to{transform:rotate(1turn)}}";

const maxTextLength = 270;
const txtLearnMore = 'Learn More';
const txtContinue = 'Continue';
const subscriptionService = SubscriptionServiceFactory.GetInstance();
const AllAppsComponent = class {
  constructor(hostRef) {
    registerInstance(this, hostRef);
    this.buttonText = {};
  }
  async loadData() {
    state.subscriptions = [];
    subscriptionService.enumerateSubscriptions().then(x => {
      state.subscriptions = [...x];
      state.subscriptions.forEach(x => {
        this.buttonText[x.subscriptionId] = txtLearnMore;
      });
    });
    state.scopedCorrelationId = AnalyticsServiceFactory.Singleton.createCorrleationId();
    AnalyticsServiceFactory.Singleton.notifyThrottle({
      category: ClickStreamCategory.AllAppsDialog,
      capturedMetrics: {
        action: ClickStreamAction.Opened,
        correlationId: state.scopedCorrelationId,
        sourceSubscriptionTitle: state.currentSubscription.title,
        timeClicked: new Date(),
      },
    });
  }
  injectCarousel(model) {
    const element = this.el.getElementsByClassName('subscription-carousel-ph')[0];
    const htmlElement = document.createElement('subscription-carousel');
    state.selectedSubscription = model;
    element.appendChild(htmlElement);
    htmlElement.presentAppDetailsModal(model);
    AnalyticsServiceFactory.Singleton.notifyThrottle({
      category: ClickStreamCategory.AllAppsDialogViewDetails,
      capturedMetrics: {
        action: ClickStreamAction.Clicked,
        correlationId: state.scopedCorrelationId,
        sourceSubscriptionId: state.selectedSubscription.subscriptionId,
        sourceSubscriptionTitle: state.selectedSubscription.title,
        timeClicked: new Date(),
      },
    });
  }
  truncateDescription(description, length) {
    if (description && description.length > length) {
      return `${description.substring(0, length)}...`;
    }
    return description;
  }
  trackClose() {
    AnalyticsServiceFactory.Singleton.notifyThrottle({
      category: ClickStreamCategory.AllAppsDialog,
      capturedMetrics: {
        action: ClickStreamAction.Closed,
        correlationId: state.scopedCorrelationId,
        timeClicked: new Date(),
      },
    });
  }
  beginButtonTransition(id, text) {
    this.buttonText[id] = text;
    this.buttonText = Object.assign({}, this.buttonText);
  }
  getText(id) {
    if (!id) {
      return txtLearnMore;
    }
    return this.buttonText[id];
  }
  render() {
    return (h(Host, null, h("marketplace-modal", { id: "all-apps-modal", width: "900px", onDialogClosed: _ => this.trackClose(), onDialogOpening: _ => this.loadData(), ref: el => (this.dialog = el) }, h("ul", { slot: "activator", class: "flex flex-row rounded cursor-pointer  btn-all-apps", id: "all-apps" }, h("li", { class: "cursor-pointer" }, h("div", { class: " flex  font-semibold text-14 flex text-white  p-2 rounded whitespace-nowrap cursor:pointer" }, h("span", { class: "font-bold text-xs" }, "All Apps")))), h("div", { slot: "content" }, h("div", { class: "py-2 ml-2 mr-2 recommended-apps-title" }, "Recommended Apps"), h("div", { class: "md:grid md:grid-cols-3 md:grid-rows-3 md:grid-flow-row md:gap-1 overflow-y-auto" }, state.subscriptions.map(UtilService.mapSubscription).map(mapped => {
      var _a, _b, _c, _d;
      return (h("div", { class: "tile rounded-lg px-2  cursor-pointer mb-6", onClick: _ => this.injectCarousel(mapped.subscription) }, h("div", { class: "focus:outline-none  flex relative " }, h("span", { class: " subscription-category-title whitespace-nowrap", title: UtilService.getCategory((_a = mapped === null || mapped === void 0 ? void 0 : mapped.subscription) === null || _a === void 0 ? void 0 : _a.metadata, 100) }, UtilService.getCategory((_b = mapped === null || mapped === void 0 ? void 0 : mapped.subscription) === null || _b === void 0 ? void 0 : _b.metadata, 100))), h("div", null, h("img", { src: UtilService.getLogoDark(mapped === null || mapped === void 0 ? void 0 : mapped.subscription.metadata, getAssetPath), class: "logo" })), h("div", { class: "paragraph overflow-hidden" }, h("span", { class: "stack-blue-text  text-xs font-medium text-left" }, this.truncateDescription((_c = mapped === null || mapped === void 0 ? void 0 : mapped.subscription) === null || _c === void 0 ? void 0 : _c.description, maxTextLength))), h("div", { class: "my-1" }, h("button", { class: "details-btn focus:outline-none   mt-2 pl-5 pr-5 pt-2 pb-2 blue-button rounded-md", onMouseEnter: () => { var _a; return this.beginButtonTransition((_a = mapped === null || mapped === void 0 ? void 0 : mapped.subscription) === null || _a === void 0 ? void 0 : _a.subscriptionId, txtContinue); }, onMouseLeave: () => { var _a; return this.beginButtonTransition((_a = mapped === null || mapped === void 0 ? void 0 : mapped.subscription) === null || _a === void 0 ? void 0 : _a.subscriptionId, txtLearnMore); } }, h("span", { class: "text-left" }, " ", this.getText((_d = mapped === null || mapped === void 0 ? void 0 : mapped.subscription) === null || _d === void 0 ? void 0 : _d.subscriptionId))))));
    })), h("div", { class: "subscription-carousel-ph" })))));
  }
  get el() { return getElement(this); }
};
AllAppsComponent.style = allAppsComponentCss;

const marketConnectComponentCss = ".modal{transition:opacity .25s ease}.btn-marketplace-connect{background-color:#0a4fb4;transition:background-color .15s}.btn-marketplace-connect:hover{background-color:#007dff}@-webkit-keyframes fadeIn{0%{opacity:0}to{opacity:1}}@keyframes fadeIn{0%{opacity:0}to{opacity:1}}@-webkit-keyframes fadeOut{0%{opacity:1}to{opacity:0}}@keyframes fadeOut{0%{opacity:1}to{opacity:0}}@-webkit-keyframes close-animation{0%{transform:rotate(0deg)}to{transform:rotate(-1turn)}}@keyframes close-animation{0%{transform:rotate(0deg)}to{transform:rotate(-1turn)}}@-webkit-keyframes open-animation{0%{transform:rotate(0deg)}to{transform:rotate(1turn)}}@keyframes open-animation{0%{transform:rotate(0deg)}to{transform:rotate(1turn)}}";

const MarketConnectComponent = class {
  constructor(hostRef) {
    registerInstance(this, hostRef);
    this.buttonClicked = createEvent(this, "buttonClicked", 7);
  }
  toggleToolbar() {
    var _a, _b;
    const p = this.el.querySelector('.plus');
    const m = this.el.querySelector('.minus');
    (_a = p === null || p === void 0 ? void 0 : p.classList) === null || _a === void 0 ? void 0 : _a.toggle('hidden');
    (_b = m === null || m === void 0 ? void 0 : m.classList) === null || _b === void 0 ? void 0 : _b.toggle('hidden');
    state.toolbarState = state.toolbarState === 'open' ? 'closed' : 'open';
    this.buttonClickedHandler(state.toolbarState);
  }
  buttonClickedHandler(state) {
    this.buttonClicked.emit(state);
  }
  componentWillLoad() {
    state.toolbarState = 'closed';
  }
  render() {
    return (h("div", { onClick: _ => this.toggleToolbar(), class: "flex items-center btn-marketplace-connect relative cursor-pointer text-14 font-semibold  text-white   py-1 px-3 whitespace-nowrap" }, h("div", { class: "flex items-center" }, h("svg", { xmlns: "http://www.w3.org/2000/svg", class: "h-4 w-4 state-button state-icon plus", fill: "none", viewBox: "0 0 24 24", stroke: "currentColor" }, h("path", { "stroke-linecap": "round", "stroke-linejoin": "round", "stroke-width": "2", d: "M12 4v16m8-8H4" })), h("svg", { xmlns: "http://www.w3.org/2000/svg", class: "h-4 w-4 state-button  state-icon hidden minus", fill: "none", viewBox: "0 0 24 24", stroke: "currentColor" }, h("path", { "stroke-linecap": "round", "stroke-linejoin": "round", "stroke-width": "2", d: "M6 18L18 6M6 6l12 12" })), h("span", { class: "hidden ml-1  lg:block" }, "Marketplace Connect"))));
  }
  get el() { return getElement(this); }
};
MarketConnectComponent.style = marketConnectComponentCss;

const myAppsComponentCss = ".my-apps{background-color:#0d194f}.my-apps:hover{background-color:#007dff}.stack-blue-800{background-color:#0d194f}.subscription-item:hover{background-color:#e5f1ff}";

const security = SecurityServiceFactory.GetInstance();
const MyApps = class {
  constructor(hostRef) {
    registerInstance(this, hostRef);
    this.visible = false;
    this.popoverActive = false;
  }
  setSubscriptionId(id) {
    security.proxySsoRequest(state.currentSubscriptionId, id);
  }
  render() {
    return [
      h("div", { class: "cursor-pointer" }, h("ul", { class: "flex flex-row  rounded text-14 flex text-white my-apps " }, h("li", { class: "cursor-pointer" }, h("div", { class: " flex font-semibold  p-2 mr- rounded whitespace-nowrap cursor:pointer", onClick: _ => { var _a; return (_a = this === null || this === void 0 ? void 0 : this.popover) === null || _a === void 0 ? void 0 : _a.show(); } }, h("span", { class: "ml-1 font-bold text-xs mr-2" }, "My Apps"), h("svg", { xmlns: "http://www.w3.org/2000/svg", class: "h-4 w-4 ", fill: "none", viewBox: "0 0 20 20", stroke: "currentColor" }, h("path", { "stroke-linecap": "round", "stroke-linejoin": "round", "stroke-width": "2", d: "M19 9l-7 7-7-7" }))), h("my-apps-popover", { ref: el => (this.popover = el) })))),
    ];
  }
  get el() { return getElement(this); }
};
MyApps.style = myAppsComponentCss;

const recommendedAppsComponentCss = ".modal{transition:opacity .25s ease}.recommendation-btn{transition:background-color .15s}.recommendation-btn:hover{background-color:#0a4fb4;color:#fff}.recommendation-btn span:hover{color:#fff}.recommendations-list{overflow-x:auto}.stack-font-color{color:#a0cdfe}";

const service = RecommendationServiceFactory.GetInstance();
const RecommendApps = class {
  constructor(hostRef) {
    registerInstance(this, hostRef);
  }
  async presentAppDetailsModal(app) {
    state.selectedSubscription = app;
    state.currentIcon = UtilService.getSvgIcon(state.selectedSubscription);
    this.dialogComponent.openDialog();
  }
  async dismissAppDetailsPopover() {
    // dismiss the closest modal and optionally pass back data
    this.el.closest('ion-modal').dismiss({
      dismissed: true,
    });
  }
  componentWillLoad() {
    if (!state.recommendations || state.recommendations.length <= 0) {
      service.getRecommendations(state.identityId).then(x => {
        state.recommendations = [...x];
      });
    }
  }
  setSlide() {
    var _a;
    (_a = this.carousel) === null || _a === void 0 ? void 0 : _a.reset();
    state.scopedCorrelationId = AnalyticsServiceFactory.Singleton.createCorrleationId();
    AnalyticsServiceFactory.Singleton.notifyThrottle({
      category: ClickStreamCategory.RecommendationDetailsDialog,
      capturedMetrics: {
        action: ClickStreamAction.Opened,
        correlationId: state.scopedCorrelationId,
        sourceSubscriptionId: state.currentSubscriptionId,
        sourceSubscriptionTitle: state.currentSubscription.title,
        timeClicked: new Date(),
      },
    });
  }
  handleBack() {
    this.carousel.goBack();
    this.pauseVideo();
  }
  pauseVideo() {
    const video = this.carousel.shadowRoot.querySelector('.marketing-video');
    if (video) {
      video.pause();
    }
    AnalyticsServiceFactory.Singleton.notifyThrottle({
      category: ClickStreamCategory.RecommendationDetailsDialog,
      capturedMetrics: {
        action: ClickStreamAction.Closed,
        correlationId: state.scopedCorrelationId,
        sourceSubscriptionId: state.currentSubscriptionId,
        sourceSubscriptionTitle: state.currentSubscription.title,
        timeClicked: new Date(),
      },
    });
    state.scopedCorrelationId = undefined;
  }
  async presentPopup(e, app) {
    e.preventDefault();
    e.stopPropagation();
    state.selectedSubscription = app;
    const popoverElement = await ComponenetFactory.injectComponenet(e.target.querySelector('#recommendation-popover-ph'), _ => {
      const element = document.createElement('recommendation-popover');
      element.classList.remove('hidden');
      return element;
    });
    this.recommendationpopover = popoverElement;
    this.recommendationpopover.classList.add('popover-active');
    UtilService.animateOnShow(this.recommendationpopover).then(_ => this.recommendationpopover.classList.add('popover-active'));
  }
  hidePopup(ev) {
    ev.preventDefault();
    ev.stopPropagation();
    let parent = ev.target.querySelector('#recommendation-popover-ph');
    if (!parent) {
      parent = ev.target;
    }
    ComponenetFactory.disposeComponenet(parent, this.recommendationpopover);
  }
  onSlideChange(e) {
    if (e && e.detail && e.detail.carouselItem) {
      const videos = e.detail.carouselItem.getElementsByTagName('video');
      if (videos.length > 0) {
        videos[0].pause();
      }
    }
  }
  render() {
    return [
      h("div", { class: "hidden lg:block" }, h("marketplace-modal", { id: "normal-recommendations-dialog", autoWireOpen: false, ref: el => (this.dialogComponent = el), onBackClicked: _ => this.handleBack(), onDialogOpening: _ => this.setSlide(), onDialogClosed: _ => this.pauseVideo(), width: "900px" }, h("div", { slot: "activator", class: "flex flex-row items-center recommendations-list  " }, h("label", { class: " text-14 p-2 stack-font-color whitespace-nowrap" }, "Recommended Apps:"), h("ul", { class: "flex flex-row", ref: el => (this.listComponent = el) }, state.recommendations
        .map(x => UtilService.mapSubscription(x))
        .map(app => (h("li", { onClick: _ => this.presentAppDetailsModal(app.subscription), onMouseEnter: e => this.presentPopup(e, app.subscription), onMouseLeave: e => this.hidePopup(e), class: "relative cursor-pointer recommendation-btn rounded p-2 ml-2 mr-4 " }, h("div", { class: " flex stack-font-color font-semibold  text-14  whitespace-nowrap cursor:pointer" }, h("span", null, UtilService.getMetadataValue(app.subscription.metadata, 'category'))), h("div", { id: "recommendation-popover-ph" })))))), h("div", { slot: "content" }, h("marketing-carousel", { ref: el => (this.carousel = el), onSlideChanged: e => this.onSlideChange(e) })))),
    ];
  }
  get el() { return getElement(this); }
};
RecommendApps.style = recommendedAppsComponentCss;

export { AllAppsComponent as all_apps, MarketConnectComponent as market_connect, MyApps as my_apps, RecommendApps as recommended_apps };
