import { r as registerInstance, d as createEvent, h, H as Host, a as getElement } from './index-3adfa07d.js';
import { C as ComponenetFactory } from './componentFactory-97ee8c5b.js';

const marketplacePopoverCss = ".popover{transition:opacity 2s ease-out}";

const MarketplacePopover = class {
  constructor(hostRef) {
    registerInstance(this, hostRef);
    this.closePopover = createEvent(this, "closePopover", 7);
    this.opening = createEvent(this, "opening", 7);
    this.popoverState = false;
  }
  onOpening() {
    this.opening.emit();
  }
  async show() {
    this.onOpening();
    this.popoverState = true;
    this.el.classList.remove('hidden');
    const animation = this.el.animate([
      // keyframes
      { opacity: 0 },
      { opacity: 1 },
    ], {
      // timing options
      easing: 'ease-in',
      duration: 100,
      iterations: 1,
    });
    return animation.finished.then(_ => {
      this.el.classList.remove('opacity-0');
      this.el.classList.add('opacity-100');
      this.el.classList.add('popover-active');
    });
  }
  async isVisible() {
    return this.popoverState;
  }
  componentWillLoad() {
    this.popoverState = false;
  }
  closePopoverdHandler(state) {
    this.popoverState = false;
    this.closePopover.emit(state);
    const animation = this.el.animate([
      // keyframes
      { opacity: 1 },
      { opacity: 0 },
    ], {
      // timing options
      easing: 'ease-out',
      duration: 250,
      iterations: 1,
    });
    animation.finished.then(_ => {
      this.el.classList.add('opactiy-0');
      this.el.classList.remove('opacity-100');
      this.el.classList.remove('popover-active');
      this.el.classList.toggle('hidden');
      this.el.parentElement.removeChild(this.el);
    });
  }
  render() {
    return (h(Host, { class: "popover opacity-0 ", onMouseLeave: _ => this.closePopoverdHandler('closed') }, h("slot", { name: "content" })));
  }
  static deactive(source, cssSelector, popover) {
    ComponenetFactory.disposeComponenet(source.querySelector(cssSelector), popover);
  }
  static activate(source, cssSelector, bodyComponent) {
    return ComponenetFactory.injectComponenet(source.querySelector(cssSelector), _ => {
      const popover = document.createElement('marketplace-popover');
      popover.innerHTML = bodyComponent;
      return popover;
    });
  }
  get el() { return getElement(this); }
};
MarketplacePopover.style = marketplacePopoverCss;

export { MarketplacePopover as marketplace_popover };
