import { S as SvgIconService } from './analytic.constants-c757efc5.js';

const icons = new SvgIconService();
let globalConfig;
class UtilService {
  static getMetadataValue(metadata, key) {
    if (metadata) {
      return metadata[key];
    }
  }
  static getIcon(metadata) {
    return UtilService.getMetadataValue(metadata, 'icon');
  }
  static getCategory(metadata, limit = 15) {
    const category = UtilService.getMetadataValue(metadata, 'category');
    if (category && category.length > limit) {
      return `${category.substring(0, limit)}....`;
    }
    return category;
  }
  static getLogo(metadata, getAssetPath) {
    return UtilService.getAsAsset(getAssetPath, UtilService.getMetadataValue(metadata, 'logo'));
  }
  static getLogoTransparent(metadata, getAssetPath) {
    const path = UtilService.getAsAsset(getAssetPath, UtilService.getMetadataValue(metadata, 'transparentLogo'));
    if (!path) {
      return '/';
    }
    return path;
  }
  static getLogoDark(metadata, getAssetPath) {
    return UtilService.getAsAsset(getAssetPath, UtilService.getMetadataValue(metadata, 'darkLogo'));
  }
  static getSvgIcon(metadata) {
    if (metadata) {
      return icons.getIcon(metadata);
    }
    else {
      const v = UtilService.getMetadataValue(metadata, 'icon');
      return icons.getIcon(v);
    }
  }
  static mapSubscription(x) {
    const iconKey = UtilService.getMetadataValue(x.metadata, 'icon');
    const t = {
      subscription: x,
      icon: icons.getIcon(iconKey),
      active: false,
    };
    return t;
  }
  static getFromCdn(path) {
    const config = UtilService.EnvironmentConfiguration();
    return `${config.cdnUri}/${path}`;
  }
  static getAsAsset(getAssetPath, path) {
    if (!path) {
      return;
    }
    if (path && path.startsWith('http')) {
      return path;
    }
    if (getAssetPath) {
      const config = UtilService.EnvironmentConfiguration();
      return getAssetPath(`${config.assetBasePath}/${path}`);
    }
    return path;
  }
  static EnvironmentConfiguration() {
    if (!globalConfig) {
      const json = window.localStorage.getItem('marketplace-config');
      globalConfig = JSON.parse(json);
      const demo = window.sessionStorage.getItem('marketplace-demo');
      if (demo) {
        globalConfig.demo = demo === 'true';
      }
    }
    return globalConfig;
  }
  static animateOnShow(element) {
    var _a, _b, _c;
    (_a = element === null || element === void 0 ? void 0 : element.classList) === null || _a === void 0 ? void 0 : _a.remove('hidden');
    (_b = element === null || element === void 0 ? void 0 : element.classList) === null || _b === void 0 ? void 0 : _b.remove('opacity-0');
    (_c = element === null || element === void 0 ? void 0 : element.classList) === null || _c === void 0 ? void 0 : _c.add('opacity-100');
    const animation = element.animate([
      // keyframes
      { opacity: 0 },
      { opacity: 1 },
    ], {
      // timing options
      easing: 'ease-in',
      duration: 150,
      iterations: 1,
    });
    return animation.finished;
  }
  static closeAnimation(startingHeight, element) {
    element.style.height = '0px';
    const animation = element.animate([
      // keyframes
      { 'max-height': startingHeight },
      { 'max-height': 0 },
    ], {
      // timing options
      easing: 'ease-in',
      duration: 150,
      iterations: 1,
    });
    return animation.finished.then(_ => {
      var _a;
      (_a = element === null || element === void 0 ? void 0 : element.classList) === null || _a === void 0 ? void 0 : _a.add('hidden');
      return element;
    });
  }
  static openAnimation(element) {
    var _a;
    (_a = element === null || element === void 0 ? void 0 : element.classList) === null || _a === void 0 ? void 0 : _a.remove('hidden');
    const startingHeight = element.clientHeight;
    element.style.height = `${startingHeight}px`;
    const animation = element.animate([
      // keyframes
      { 'max-height': 0 },
      { 'max-height': startingHeight },
    ], {
      // timing options
      easing: 'ease-in',
      duration: 150,
      iterations: 1,
    });
    return animation.finished.then(_ => {
      return element;
    });
  }
  static animateOnHide(element) {
    const animation = element.animate([
      // keyframes
      { opacity: 1 },
      { opacity: 0 },
      {},
    ], {
      // timing options
      easing: 'ease-out',
      duration: 150,
      iterations: 1,
    });
    return animation.finished.then(_ => {
      var _a;
      element === null || element === void 0 ? void 0 : element.classList.add('opacity-0');
      element === null || element === void 0 ? void 0 : element.classList.remove('opacity-100');
      (_a = element === null || element === void 0 ? void 0 : element.classList) === null || _a === void 0 ? void 0 : _a.add('hidden');
      return element;
    });
  }
}

export { UtilService as U };
